diff --git a/dumux/multidomain/facet/gridmanager.hh b/dumux/multidomain/facet/gridmanager.hh
index 17342b2ba6dbc2ca78092fe9e46afce4cdb2c34e..4382b5f529040df4a24b423b23ebbefa10f9fd79 100644
--- a/dumux/multidomain/facet/gridmanager.hh
+++ b/dumux/multidomain/facet/gridmanager.hh
@@ -215,14 +215,22 @@ public:
         else return typename std::unordered_map< GridIndexType, std::vector<GridIndexType> >::mapped_type();
     }
 
-    //! Returns the maps of the embedded entities
+    //! Returns const reference to maps of the embedded entities
     const std::unordered_map< GridIndexType, std::vector<GridIndexType> >& embeddedEntityMap(std::size_t id) const
     { assert(id < numGrids); return embeddedEntityMaps_[id]; }
 
-    //! Returns the maps of the adjoined entities of dimension d+1
+    //! Returns non-const reference to maps of the embedded entities
+    std::unordered_map< GridIndexType, std::vector<GridIndexType> >& embeddedEntityMap(std::size_t id)
+    { assert(id < numGrids); return embeddedEntityMaps_[id]; }
+
+    //! Returns const reference to the maps of the adjoined entities of dimension d+1
     const std::unordered_map< GridIndexType, std::vector<GridIndexType> >& adjoinedEntityMap(std::size_t id) const
     { assert(id < numGrids); return adjoinedEntityMaps_[id]; }
 
+    //! Returns non-const reference to the maps of the adjoined entities of dimension d+1
+    std::unordered_map< GridIndexType, std::vector<GridIndexType> >& adjoinedEntityMap(std::size_t id)
+    { assert(id < numGrids); return adjoinedEntityMaps_[id]; }
+
     //! Returns the hierachy's insertion indices that make up the grid for the given id
     const std::vector<GridIndexType>& lowDimVertexIndices(std::size_t id) const
     { assert(id > 0 && id < numGrids); return lowDimGridVertexIndices_[id-1]; }